from .koinex import Koinex
from .zebpay import Zebpay
from .unocoin import Unocoin

class Ckandr(object):
    """Main Ckandr class"""

    def __init__(self):
        self.main()

    def main(self):
        koinex = Koinex()
        koinex.get_koinex_rates()
        zebpay = Zebpay()
        zebpay.get_zebpay_rates()
        #unocoin = Unocoin()
        #unocoin.get_unocoin_rates()



import os
import requests
from terminaltables import DoubleTable

class Zebpay(object):
    """Main Zebpay Class"""

    def __init__(self):
        self.URL = "https://www.zebapi.com/api/v1/market/ticker/btc/inr"
        self.title = "\033[94mZebpay CryptoCurrency Rates\033[0m"
        self.cryptos = {
            "BTC": "BitCoin"
        }


    def get_zebpay_rates(self):
        print("")
        try:
            response = requests.get(self.URL)
        except Exception as e:
            print(type(e).__name__)
        if response and response.status_code == 200:
            zebpay_data = response.json()
            zebpay_list = []
            zebpay_list.append(['CryptoCurrency Name', 'Symbol', 'Buy Rate', 'Sell Rate'] )
            for curr in self.cryptos:
                zebpay_list.append([self.cryptos[curr], curr, zebpay_data['buy'], zebpay_data['sell'] ])
            table = DoubleTable(zebpay_list)
            table.title = self.title
            table.inner_row_border = True
            print (table.table)



import os
import requests
from terminaltables import DoubleTable

class Koinex(object):
    """Main Koinex Class"""

    def __init__(self):
        self.URL = "https://koinex.in/api/ticker"
        self.title = "\033[94mKoinex CryptoCurrency Rates\033[0m"
        self.cryptos = {
            "BTC": "BitCoin",
            "ETH": "Ethereum",
            "XRP": "Ripple",
            "BCH": "Bitcoin Cash",
            "LTC": "LiteCoin"
        }


    def get_koinex_rates(self):
        os.system('clear')
        try:
            response = requests.get(self.URL)
        except Exception as e:
            print(type(e).__name__)
        if response and response.status_code == 200:
            koinex_data = response.json()
            koinex_list = []
            koinex_list.append(['CryptoCurrency Name', 'Symbol', 'Price'] )
            for curr in self.cryptos:
                koinex_list.append([self.cryptos[curr], curr, koinex_data['prices'][curr]])
            table = DoubleTable(koinex_list)
            table.title = self.title
            table.inner_row_border = True
            print (table.table)



# Ckandr

from setuptools import setup

def requirements():
    """Build the requirements list for this project"""
    requirements_list = []

    with open('requirements.txt') as requirements:
        for install in requirements:
            requirements_list.append(install.strip())

    return requirements_list

long_description = """
About
-----
ckandr is a python-based command-line application Cryptocurrency prices from popular Indian cryptocurrency exchanges.
There are already some great command-line cryptocurrency price ticker tools like `Coinmon`_ and it's python port `Pycoinmon`_.
ckandr is heavily inspired by both these projects.
However, both these projects get their data from `CoinMarketCap`_'s API. This is of no use to Indian investors who are investing through Indian exchanges like `Koinex`_, `ZebPay`_ and others.
ckandr aims to solve this problem by fetching prices from these sites (and more to follow soon).

For all you non-Hindi speaking people out there, ckandr is a play on a Hindi word, Sikander, which means a "warrior" or "defender". And the pseudo-acronym of ckandr, Crypto KA Naya Desi Rate, just means the latest price of cryptocurrencies in Rupees(INR).

Usage
-----
It's as easy as:

::

    $ ckandr

Screenshot
----------

.. figure:: https://raw.githubusercontent.com/screwgoth/ckandr/master/ckandr_screenshot.png
   :alt: ckandr screenshot

.. _Coinmon : https://github.com/bichenkk/coinmon
.. _Pycoinmon : https://github.com/RDCH106/pycoinmon
.. _Koinex : http://koinex.in
.. _ZebPay : http://zebpay.com
.. _CoinMarketCap: https://coinmarketcap.com/

    """

setup(
    name = 'ckandr',
    packages = ['ckandr'],
    install_requires = ['certifi==2017.11.5', 'chardet==3.0.4', 'idna==2.6', 'requests==2.18.4', 'terminaltables==3.1.0', 'urllib3==1.22'],
    version = '0.1.1',
    license = 'MIT',
    description = 'Cryptocurrency Ka Naya Desi Rate : Cryptocurrency prices from Indian exchanges',
    long_description= long_description,
    author = 'Raseel Bhagat',
    author_email = 'raseelbhagat@gmail.com',
    url = 'https://github.com/screwgoth/ckandr',
    download_url = 'https://github.com/screwgoth/ckandr/archive/0.1.tar.gz',
    entry_points={
        'console_scripts': ['ckandr=ckandr.main:main'],
    },
    #scripts=['ckandr/main.py'],
    keywords = 'bitcoin cryptocurrency ticker python cli price-tracker command-line',
    classifiers = ['Programming Language :: Python',
                   'Programming Language :: Python :: 2.7',
                   'Programming Language :: Python :: 3.2',
                   'Programming Language :: Python :: 3.3',
                   'Programming Language :: Python :: 3.4',
                   'Programming Language :: Python :: 3.5',
                   'Programming Language :: Python :: 3.6'],
)



import os
import requests
from terminaltables import DoubleTable

class Unocoin(object):
    """Main Unocoin Class"""

    def __init__(self):
        self.URL = "https://www.unocoin.com/trade?all"
        self.title = "Unocoin CryptoCurrency Rates"
        self.cryptos = {
            "BTC": "BitCoin"
        }


    def get_unocoin_rates(self):
        print("")
        try:
            response = requests.get(self.URL)
        except Exception as e:
            print(type(e).__name__)
        if response and response.status_code == 200:
            unocoin_data = response.json()
            unocoin_list = []
            unocoin_list.append(['CryptoCurrency Name', 'Symbol', 'Buy Rate', 'Sell Rate'] )
            for curr in self.cryptos:
                unocoin_list.append([self.cryptos[curr], curr, unocoin_data['buy'], unocoin_data['sell'] ])
            table = DoubleTable(unocoin_list)
            table.title = self.title
            table.inner_row_border = True
            print (table.table)
